/** \file buf.h General-purpose dynamic buffer include file.
 * \author Darryl Luff	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 2002 Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __BUF_H
#define __BUF_H

/** Buffer structure.	*/
typedef struct _a_buf {
	unsigned char *b_dat;	/**< Pointer to the buffer data.	*/
	unsigned int b_len;		/**< Length of the allocated buffer.	*/
} ABuf;

/** Allocate a new buffer.	*/
ABuf *buf_new(unsigned int len);
/** Free a buffer_handle_type*/
ABuf *buf_free(ABuf * buf);
/** Check that the buffer is at least 'len' bytes.	*/
ABuf *buf_check(ABuf * buf, unsigned int len);
/** append the string 's' to the buffer.	*/
ABuf *buf_strcat(ABuf * buf, char *s);
/** Copy the string 's' into the buffer, replacing whatever's there.	*/
ABuf *buf_strcpy(ABuf * buf, char *s);
/** Shrinks the char string in the buffer by one character.	*/
ABuf *buf_str_shrinkbyone(ABuf * buf);
/** Ensure that the last char in the buffer contains '\0'.	*/
ABuf *buf_terminate(ABuf * buf);

#endif
