/** \file db_conn.c	Functions for manipulating DBConnection's.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup db	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL and MySQL. 
 * Copyright (C) 1998-2003  Lionel ULMER, Darryl Luff
 * MySQL "driver" (C) 1998 Des Herriott (des@ops.netcom.net.uk)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "../config.h"

#include <stdlib.h>
#include <string.h>

#include "db_conn.h"

/** Add a keyword to the keyword-completion list.
 * \param conn	The database connection.
 * \param key	The keyword.
 * \param type	The type of keyword.	*/
void add_keyword(DBConnection * conn, char *key, int type)
{
	Keyword *cur, *prev = NULL, *now = conn->keylist;

	cur = (Keyword *) malloc(sizeof(Keyword));
	cur->key = strdup(key);
	cur->type = type;

	while (now != NULL) {
		int cmp = strcasecmp(cur->key, now->key);

		if (cmp < 0) {
			cur->next = now;
			if (prev != NULL)
				prev->next = cur;
			else
				conn->keylist = cur;
			break;
		}
		else if (cmp == 0) {
			if (cur->type < now->type) {
				cur->next = now;
				if (prev != NULL)
					prev->next = cur;
				else
					conn->keylist = cur;
				break;
			}
			else if (cur->type == now->type) {
				break;
			}
		}
		prev = now;
		now = now->next;
	}
	if (now == NULL) {
		cur->next = NULL;
		if (prev != NULL)
			prev->next = cur;
		else
			conn->keylist = cur;
	}
}

/** Find a connector for a specified database type.
 * \param key	The type name. This needs to match the 'dbtype' field in the
 * DBConnector structure.
 * \return A pointer to the connector, or NULL.	*/
DBConnector *dbconnector_find(char *key) {
	int i = 1;
	DBConnector *dbc;
	dbc = connectorTable[i];
	while (dbc != NULL) {
		if (strcasecmp(dbc->dbtype, key) == 0)
			return dbc;

		i++;
		dbc = connectorTable[i];
	}
	return NULL;
}

/** Clear the keyword list of all entries.
 * \param conn	The database connection.	*/
void keywords_remove_all(DBConnection * conn)
{
	Keyword *next, *cur = conn->keylist;

	while (cur != NULL) {
		next = cur->next;

		free(cur->key);
		free(cur);

		cur = next;
	}
}

/** Clear all keywords of the specified type.
 * \param conn	The database connection.
 * \param type	The type of keywords to remove.	*/
void keywords_remove(DBConnection * conn, int type)
{
	Keyword *prev = NULL, *cur = conn->keylist, *next;

	while (cur != NULL) {
		next = cur->next;

		if (cur->type == type) {
			if (prev == NULL)
				conn->keylist = cur->next;
			else
				prev->next = cur->next;
			free(cur->key);
			free(cur);
		}
		else {
			prev = cur;
		}
		cur = next;
	}
}
