/** \file dialogs.h	Dialog module include file.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998  Lionel ULMER
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Dialog routine.
 */

#ifndef __DIALOGS_H__
#define __DIALOGS_H__

#include <gtk/gtk.h>

/** The predefined standard dialog types.	*/
typedef enum {
	DLGTYPE_NONE = 0,	/**< Not a predefined dialog.	*/
	DLGTYPE_WARNING,	/**< A warning dialog.	*/
	DLGTYPE_QUESTION	/**< A question dialog.	*/
} DlgType;

/** Creates a default dialog.	*/
GtkWidget *create_standard_dialog(const char *title, const char *text,
								  const DlgType predefined_type, char **pixmap,
								  const char *ok_text, void (*ok_callback) (void *),
								  const char *cancel_text,
						 		  void (*cancel_callback) (void *),
								  void *callback_data);

/** Create a standard warning dialog.	*/
GtkWidget *create_warning_dialog(const char *title, const char *text);

void display_error(char *title, char *message);

void file_open_dialog(GtkWidget *txt);

/** Create and show a standard warning dialog.	*/
GtkWidget *show_warning_dialog(char *title, char *text);

#endif
