/** \file drag.c	Drag/drop routines.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui
 *
 * This file contains functions to manage the dragging of text from 
 * the table view to the query window.	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 2002  Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * --------------------------------------------------------------------------
 * drag.c
 *
 * Handles dragging and dropping of text between the table list and the query window.
 *
 */

#include <string.h>
#include "buf.h"
#include "drag.h"

/** Called when receives dropped data.	*/
void receive_callback(GtkWidget * widget, GdkDragContext * context, gint x,
					 gint y, GtkSelectionData * selection, guint info,
					 guint time)
{
	if (selection->length < 0) {
		g_warning("Selection retrieval failed\n");
		return;
	}

	if (selection->type != selection->target) {
		g_warning("Selection type is wrong\n");
		return;
	}
	gtk_text_insert(GTK_TEXT(widget), NULL, NULL, NULL, selection->data,
					strlen(selection->data));
	return;
}

/** Called when dragging starts.	*/
void send_callback(GtkWidget * widget, GdkDragContext * context,
				  GtkSelectionData * selection, guint info, guint time)
{
	GtkCList *clist;
	GList *list;
	int row = 0;
	char *field;
	ABuf *fields = buf_new(1024);
	int focus = -1;

	if (! fields) {
		g_error("sendCallback() could not allocate memory for a buffer\n");
		return;
	}
	clist = GTK_CLIST(widget);
	gtk_clist_get_text(clist, row, 0, &field);

	focus = clist->focus_row;
	gtk_clist_get_text(clist, focus, 0, &field);
	strncpy(fields->b_dat, field, fields->b_len);

	list = clist->selection;
	while (list) {
		row = (int) list->data;
		if (row != focus) {
			gtk_clist_get_text(clist, row, 0, &field);
			fields = buf_check(fields, strlen(fields->b_dat) + strlen(field) + 3);
			fields = buf_strcat(fields, ", ");
			fields = buf_strcat(fields, field);
		}
		list = list->next;
	}

	gtk_selection_data_set(selection, selection->target, 8,
						   (const guchar *) fields->b_dat, strlen(fields->b_dat) + 1);
	buf_free(fields);
}
