/** \file gui_common.c Common GUI functions.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998-2003  Lionel ULMER, Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "dialogs.h"
#include "support.h"

/** Non-zero when gtk main loop is running.	*/
int running = 0;


/* Other Widgets	*/
/** The notebook holding the queries.	*/
GtkWidget *queryNotebook = NULL;

/**< The notebook holding the results.	*/
GtkWidget *resultNotebook = NULL;

/** Main window.	*/
GtkWidget *mainWindow = NULL;
/** About dialog.	*/
GtkWidget *aboutDialog = NULL;
/** Query Import dialog.	*/
GtkFileSelection *queryImportDialog = NULL;
/** Query Save dialog.	*/
GtkFileSelection *querySaveDialog = NULL;
/** Script Open dialog.	*/
GtkWidget *scriptOpenDialog = NULL;

/** Script Save dialog.	*/
GtkWidget *scriptSaveDialog = NULL;

/* Main menu widgets	*/

/* Main Config menu.	*/
GtkWidget *mainmenu_databaseConnect = NULL;		/**< 'Connect' menu item.	*/
GtkWidget *mainmenu_databaseDisconnect = NULL;	/**< 'Disconnect' menu item.	*/

GtkWidget *mainmenu_fileScriptLoad = NULL;		/**< 'Script Load' menu item.	*/
GtkWidget *mainmenu_fileScriptSave = NULL;		/**< 'Script Save' menu item.	*/
GtkWidget *mainmenu_fileQueryImport = NULL;		/**< 'Import' menu item.	*/
GtkWidget *mainmenu_fileQueryLoad = NULL;		/**< 'Load' menu item.	*/
GtkWidget *mainmenu_fileQuerySave = NULL;		/**< 'Save Query' menu item.	*/
GtkWidget *mainmenu_fileQuerySaveAs = NULL;		/**< 'Save Query As' menu item.	*/
GtkWidget *mainmenu_fileResultExport = NULL;	/**< 'Export' menu item.	*/

GtkWidget *mainmenu_queryClear = NULL;			/**< 'Clear' menu item.	*/
GtkWidget *mainmenu_queryClose = NULL;			/**< 'Close' menu item.	*/
GtkWidget *mainmenu_queryNew = NULL;			/**< 'New' query menu item.	*/
GtkWidget *mainmenu_querySend = NULL;			/**< 'Send' menu item.	*/

GtkWidget *mainmenu_tableRefresh = NULL;		/**< 'Refresh' menu item.	*/


/** Cancel callback used by the Import and Save dialog.
 * \param widget	The cancel button.
 * \param data	The dialog pointer.	*/
void common_cancel_callback(GtkWidget * widget, gpointer data)
{
	GtkWidget *fd = (GtkWidget *) data;
	gtk_widget_hide(GTK_WIDGET(fd));
}

/** Count the pages in a GTK notebook.
 * \param nb	The notebook.
 * \return The page count, or -1 on error.	*/
int notebook_page_count(GtkNotebook *nb) {
	GList *children;

	if (nb == NULL)
		return -1;

	children = gtk_container_children(GTK_CONTAINER(nb));
	if (children == NULL)
		return -1;

	return g_list_length(children);
}

/** Setup the global widget variables.	*/
void setup_widget_vars() {
	mainmenu_databaseConnect = lookup_widget(mainWindow, "mainmenu_databaseConnect");
	mainmenu_databaseDisconnect = lookup_widget(mainWindow, "mainmenu_databaseDisconnect");

	mainmenu_fileQueryImport = lookup_widget(mainWindow, "mainmenu_fileQueryImport");
	mainmenu_fileQueryLoad = lookup_widget(mainWindow, "mainmenu_fileQueryLoad");
	mainmenu_fileQuerySave = lookup_widget(mainWindow, "mainmenu_fileQuerySave");
	mainmenu_fileQuerySaveAs = lookup_widget(mainWindow, "mainmenu_fileQuerySaveAs");
	mainmenu_fileResultExport = lookup_widget(mainWindow, "mainmenu_fileResultExport");

	mainmenu_fileScriptSave = lookup_widget(mainWindow, "mainmenu_fileScriptSaveAs");
	mainmenu_fileScriptLoad = lookup_widget(mainWindow, "mainmenu_fileScriptLoad");

	mainmenu_queryClear = lookup_widget(mainWindow, "mainmenu_queryClear");
	mainmenu_queryClose = lookup_widget(mainWindow, "mainmenu_queryClose");
	mainmenu_queryNew = lookup_widget(mainWindow, "mainmenu_queryNew");
	mainmenu_querySend = lookup_widget(mainWindow, "mainmenu_querySend");

	mainmenu_tableRefresh = lookup_widget(mainWindow, "mainmenu_tableRefresh");
}

void show_error_message(gchar *title, gchar *msg) {
	GtkWidget *dialog = create_standard_dialog("Error in query name", "You need to specify a non empty name.", 1, NULL, "Ok", NULL, NULL, NULL, NULL);
	gtk_widget_show(dialog);
}

/** Function to display the widget path and class path for a GtkWidget.
 * This is mainly used for debugging and doesn't have a use in the 
 * final application.
 * \param	widget	The widget to test.
 * \param	id	A text string that is displayed at the start of the line,
 * so you can tell multiple widget dumps apart.	*/
void show_widget_paths(GtkWidget *widget, char *id) {
	gchar *path = NULL;
	gint plen = 2048;

	if (! widget)
		return;

	gtk_widget_path(GTK_WIDGET(widget), &plen, &path, NULL);
	g_print("%s: widget path = %s\n", id, path);

	gtk_widget_class_path(GTK_WIDGET(widget), &plen, &path, NULL);
	g_print("%s: widget class path = %s\n", id, path);
}
