/** \file gui_common.h Common GUI items.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998-2003  Lionel ULMER, Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __COMMON_H__
#define __COMMON_H__

#include "../config.h"

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>

#include "appconfig.h"

extern int running;

extern GtkWidget *queryNotebook;	
extern GtkWidget *resultNotebook;
extern GtkWidget *queryExportItem;

extern GtkWidget *mainWindow;
extern GtkWidget *aboutDialog;
extern GtkFileSelection *queryImportDialog;
extern GtkFileSelection *querySaveDialog;
extern GtkWidget *scriptOpenDialog;
extern GtkWidget *scriptSaveDialog;

extern GtkWidget *mainmenu_databaseConnect;
extern GtkWidget *mainmenu_databaseDisconnect;

extern GtkWidget *mainmenu_fileQueryImport;
extern GtkWidget *mainmenu_fileQueryLoad;
extern GtkWidget *mainmenu_fileQuerySave;
extern GtkWidget *mainmenu_fileQuerySaveAs;
extern GtkWidget *mainmenu_fileResultExport;
extern GtkWidget *mainmenu_fileScriptLoad;
extern GtkWidget *mainmenu_fileScriptSave;

extern GtkWidget *mainmenu_queryClear;
extern GtkWidget *mainmenu_queryClose;
extern GtkWidget *mainmenu_queryNew;
extern GtkWidget *mainmenu_querySend;

extern GtkWidget *mainmenu_tableRefresh;


/** Application name.	*/
#define APPNAME "GtkSQL"							

/** Contact email address.	*/
#define MAIL    "djluff@users.sourceforge.net"

/** Application URL.	*/
#define URL     "http://gtksql.sourceforge.net/"

/** Adjust the active state of the buttons the match the application state.	*/
void update_button_sensitivity();

/** Cancels a dialog by hiding it. Relies on 'data' being a pointer to the
 * dialog.	*/
void common_cancel_callback(GtkWidget * widget, gpointer data);

/** Count the pages in a GTK notebook.	*/
int notebook_page_count(GtkNotebook *nb);

void setup_widget_vars();

#endif
