/** \file queries.h	Interface to query display module.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998-2002  Lionel ULMER, Darryl Luff.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * ==========================================================================
 *
 * Functions for managing the query and result windows.
 */

#ifndef __QUERIES_H__
#define __QUERIES_H__

#include <gtk/gtk.h>
#include "querydata.h"

/** Maximum result column width  */
#define MAXCOLWID 25

#define RESULT_KEY	"Result"
#define STATUS_KEY	"Message"

typedef enum {
	QUERY_NEW = 0,
	QUERY_SWITCH,
	QUERY_FAKE,
	QUERY_ERROR
} QueryDisplay;

extern int lastQuery;
extern int nbQueries;
extern int queryStatus;

extern GtkWidget *queryPopupClearItem;
extern GtkWidget *queryPopupCloseItem;
extern GtkWidget *queryPopupImportItem;
extern GtkWidget *queryPopupNewItem;
extern GtkWidget *queryPopupSaveItem;
extern GtkWidget *queryPopupSaveAsItem;
extern GtkWidget *queryPopupSendItem;


extern void do_export_dialog(GtkWidget * widget, gpointer data);

/** Reference to the query notebook page change handler.	*/
extern guint queryNotebookPageChangeHandler;

/** Close the current query.	*/
int query_close();

/** Delete the selected query. The position index is zero-based.	*/
int query_delete_at_position(int position);

GtkWidget *query_get_current();
char *query_get_current_name();

void *get_current_query_result();

/** Return the query text widget selected by 'n'. 'n' is zero-based.	*/
void *query_get_current_result(void);

/** Retrieve a query widget by it's index number.	*/
GtkWidget *query_get_no(int n);
char *query_get_text_no(int n);

/** Get the query data for the passed query.	*/
QueryData *query_get_querydata(GtkWidget *query);
void *query_get_result(GtkWidget * query);

/** Initilise the query notebook.	*/
GtkWidget *query_pane_init();
void queries_init();

/** Initilise the result notebook.	*/
GtkWidget *result_pane_init();

/** Display the results in the result pane.	*/
void results_display(void *result, int why, int position);

/** Import a file into the current query.	*/
void query_import(void);
/** Clear the current query.	*/
void query_clear(void);
/** Return the umber of queries.	*/
int query_count();

/** Add a new query and associated result page.	*/
GtkWidget *query_add(void);

/** Return text of listed query page.	*/
char *query_get_text(GtkWidget * query);

/** Save a query to disk.
 * \param qry	The query to save. If NULL, the current query is saved.	*/
void query_save(GtkWidget *qry);
/** Save the current query to a file under a new name.	*/
void query_save_as(GtkWidget *qry);
/** Save the query to a specific file.	*/
void query_save_to_file(GtkWidget *query, char *fn);
/** Set the name of the query notebook page.	*/
void query_set_name(int position, char *name);

#endif
