/** \file query_save_dlg.c	Query save dialog.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL and MySQL.
 * Copyright (C) 1998-2003  Lionel ULMER, Darryl Luff.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of tdo_he License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>

#include "buf.h"
#include "gui_common.h"
#include "interface.h"
#include "queries.h"
#include "query_save_dlg.h"

/* ==== Variables ==== */
QuerySaveData querySaveData = {
	NULL, NULL
};

/** Hide the query save dialog.	*/
void query_save_dialog_hide()
{
	if (querySaveDialog != NULL)
		gtk_widget_hide(GTK_WIDGET(querySaveDialog));
}

/** Creates the query save dialog.
 * \param qry	The query to save. If NULL, save the current query.
 */
void query_save_dialog_create(GtkWidget * qry)
{
	ABuf *buf = NULL;

	if (querySaveDialog == NULL) {
		querySaveDialog = GTK_FILE_SELECTION(create_querySaveDlg());

		buf = buf_strcpy(buf, cfg_get_current_dir());
		buf = buf_strcat(buf, "/");
		buf = buf_strcat(buf, query_get_current_name());
		buf = buf_strcat(buf, ".sql");
		gtk_file_selection_set_filename(GTK_FILE_SELECTION(querySaveDialog),
										buf->b_dat);
		buf_free(buf);
	}

	querySaveData.query = qry;
	if (qry == NULL)
		querySaveData.qdata = NULL;
	else
		querySaveData.qdata = query_get_querydata(qry);

	if (querySaveData.qdata != NULL)
		gtk_file_selection_set_filename(GTK_FILE_SELECTION(querySaveDialog),
										querydata_get_filename(querySaveData.
															   qdata));
}

void query_save_dialog_show(GtkWidget * qry)
{
	query_save_dialog_create(qry);
	gtk_widget_show(GTK_WIDGET(querySaveDialog));
}
