/** \file querydata.h	Interface to query data module.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998-2002  Lionel ULMER, Darryl Luff.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * ==========================================================================
 *
 */

#ifndef __QUERYDATA_H__
#define __QUERYDATA_H__

#define QDATA_KEY   "QueryData"

/** Data for the Query rename dialog.	*/
typedef struct _queryData {
	int		changed;	/**< Flags changes since last save.	*/
	char	*filename;	/**< Filename on disk.	*/
} QueryData;

/** Allocate a new QueryData structure.	*/
QueryData *querydata_new();

/** Free a QueryData structure.	*/
QueryData *querydata_free(QueryData *qd);

/** Get the filename.	*/
char *querydata_get_filename(QueryData *qd);

/** Set the value of the 'changed' flag.	*/
void querydata_set_changed(QueryData *qd, int c);

/** Check if the query has been changed since the last save.	*/
int querydata_is_changed(QueryData *qd);

/** Allocate a new QueryData structure.	*/
void querydata_set_filename(QueryData *qd, char *fn);

/** Mark a query as unchanged.	*/
void querydata_set_unchanged(QueryData *qd);

#endif
