/** \file status.c	Status bar functions.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998-2003 Lionel Ulmer, Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdlib.h>
#include <gtk/gtk.h>

#include "status.h"

static GtkWidget *hbox;
static GtkWidget *sbar;
static guint contextId;
static GtkWidget *pbar;

/** Allocate and return the status bar.
 * \return	The status bar widget.	*/
GtkWidget *status_bar_new(void)
{
	hbox = gtk_hbox_new(FALSE, 5);
	sbar = gtk_statusbar_new();
	contextId = gtk_statusbar_get_context_id(GTK_STATUSBAR(sbar),
											  "GtkSQL status");
	gtk_widget_show(sbar);
	pbar = gtk_progress_bar_new();
	gtk_widget_set_usize(pbar, 150, 20);
	gtk_widget_show(pbar);

	gtk_box_pack_start(GTK_BOX(hbox), sbar, TRUE, TRUE, 0);
	gtk_box_pack_start(GTK_BOX(hbox), pbar, FALSE, FALSE, 0);

	return hbox;
}

/** Pop the last entry off the statusbar stack.	*/
void status_pop(void)
{
	gtk_statusbar_pop(GTK_STATUSBAR(sbar), contextId);
	while (gtk_events_pending())
		gtk_main_iteration();
}

/** Push a new message onto the status bar stack.	*/
void status_push(gchar * msg)
{
	gtk_statusbar_push(GTK_STATUSBAR(sbar), contextId, msg);
	while (gtk_events_pending())
		gtk_main_iteration();
}

/** Reset the progress bar.	*/
void progress_reset(void)
{
	gtk_progress_bar_update(GTK_PROGRESS_BAR(pbar), 0.0);
	while (gtk_events_pending())
		gtk_main_iteration();
}

/** Update the progress bar.	*/
void progress_update(gfloat percentage)
{
	gtk_progress_bar_update(GTK_PROGRESS_BAR(pbar), percentage);
	while (gtk_events_pending())
		gtk_main_iteration();
}
