/** \file utils.c	Utility routines.
 * \author Lionel ULMER
 * \author Darryl Luff
 * \ingroup misc	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 2003 Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <ctype.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

/** \param f	The file to write to.
 * \param exists	How many characters are used in the field.
 * \param todo	The required field width.	*/
void add_space(FILE * f, const int exists, const int todo)
{
	int i;

	for (i = exists; i < todo; i++)
		fputc(' ', f);
}

static char *ttBuf = NULL;
static int ttBuflen = 0;
/** Returns a copy of the passed string with leading whitespace
 * removed. The pointer returned is to a static buffer, so don't
 * free it. The contents will be overwritten on the next call to
 * this function so if you need to keep it, make a copy (like 
 * char *mystring = strdup(trimtext("   hello"));.	*/
char *trimtext(const char *s) {
	char *dp;
	const char *sp;

	if (! s)
		return "";

	if (ttBuflen < (strlen(s) + 1)) {
		if (ttBuf)
			free(ttBuf);

		ttBuflen = strlen(s)+1;
		ttBuf = malloc(ttBuflen);
	}
	sp = s;
	dp = ttBuf;

	/* skip leading spaces	*/
	while ((*sp) && (isspace(*sp)))
		sp++;

	/* now just copy to end of string	*/
	while (*sp) {
		*dp = *sp;
		dp++;
		sp++;
	}

	*dp = '\0';
	return ttBuf;
}

/** Get the shortened filename (without the path).
 * \param fn	The full filename to parse.
 * \return	The short filename. This is a pointer into the 'fn' string, so 
 * don't free 'fn' till you've gfinished with this result.	*/
char *get_short_filename(char *fn) {
	char *sfn;
	char *p;
	if (fn == NULL)
		return NULL;

	sfn = fn;
	p = strchr(sfn, '/');
	while (p != NULL) {
		sfn = p;
		sfn++;
		p = strchr(sfn, '/');
	}

	/* Now, p should be null, meaning that there are no more '/'s, and
	 * 'sfn' should point to the short name.	*/
	return sfn;
}
